class PlatformError(Exception):
    """
    The error is thrown when you try to use function
    that are only available for windows
    """